import {Service} from '@overflow/commons/api/service';

export class ServiceInvoker {
    private config: Map<string, Service>;
    private instanceMap: Map<string, Object>;

    public constructor(config: Map<string, Service>) {
        this.config = config;
        this.instanceMap = new Map();

        this.initialize();
    }

    private initialize(): void {
        this.config.forEach((value, key) => {
            this.instanceMap.set(key, Object.create(value));
        });
    }

    public invoke(className: string, methodName: string, params?: any): void {
        let classObj: Object = this.instanceMap.get(className);
        if (classObj === null || classObj === undefined) {
            console.log('Error: Cannot find the class. [' + className + ']');
            return;
        }
        if (classObj[methodName] === undefined) {
            console.log('Error: Cannot find the method. [' + methodName + ']');
            return;
        }
        classObj[methodName](params);
    }
}


export default ServiceInvoker;
